==> owncloud-8.2.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/fa.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "فضای ذخیره سازی موجود نیست",
    "Storage invalid" : "فضای ذخیره‌سازی نامعتبر",
    "Unknown error" : "خطای نامشخص",
    "Could not move %s - File with this name already exists" : "%s نمی توان جابجا کرد - در حال حاضر پرونده با این نام وجود دارد. ",
    "Could not move %s" : "%s نمی تواند حرکت کند ",
    "Permission denied" : "رد دسترسی",
    "The target folder has been moved or deleted." : "پوشه مقصد انتقال یافته یا حذف شده است.",
    "The name %s is already used in the folder %s. Please choose a different name." : "نام %s هم‌اکنون در پوشه %s مورد استفاده قرار گرفته شده است. لطفا نام دیگری انتخاب کنید.",
    "Error when creating the file" : "خطا در حین ایجاد فایل",
    "Error when creating the folder" : "خطا در حین ایجاد پوشه",
    "Unable to set upload directory." : "قادر به تنظیم پوشه آپلود نمی باشد.",
    "Invalid Token" : "رمز نامعتبر",
    "No file was uploaded. Unknown error" : "هیچ فایلی آپلود نشد.خطای ناشناس",
    "There is no error, the file uploaded with success" : "هیچ خطایی نیست بارگذاری پرونده موفقیت آمیز بود",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "پرونده آپلود شده بیش ازدستور  ماکزیمم_حجم فایل_برای آپلود در   php.ini استفاده کرده است.",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "حداکثر حجم قابل بار گذاری از طریق HTML MAX_FILE_SIZE است",
    "The uploaded file was only partially uploaded" : "پرونده بارگذاری شده فقط تاحدودی بارگذاری شده",
    "No file was uploaded" : "هیچ پروندهای بارگذاری نشده",
    "Missing a temporary folder" : "یک پوشه موقت گم شده",
    "Failed to write to disk" : "نوشتن بر روی دیسک سخت ناموفق بود",
    "Not enough storage available" : "فضای کافی در دسترس نیست",
    "Upload failed. Could not find uploaded file" : "خطا در آپلود. امکان یافتن فایل‌های آپلود شده وجود ندارد",
    "Upload failed. Could not get file info." : "خطای آپلود. امکان دریافت جزئیات فایل وجود ندارد.",
    "Invalid directory." : "فهرست راهنما نامعتبر می باشد.",
    "Files" : "پرونده‌ها",
    "All files" : "تمامی فایل‌ها",
    "Favorites" : "موارد محبوب",
    "Home" : "خانه",
    "Close" : "بستن",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "امکان آپلود {filename} وجود ندارد، پوشه‌ای با این نام یا فایلی با حجم 0 بایت با این نام وجود دارد",
    "Total file size {size1} exceeds upload limit {size2}" : "مجموع سایز {size1} بیشتر از محدودیت آپلود {size2} است",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "ظرفیت لازم وجود ندارد، شما آپلودی با حجم {size1}  را انجام میدهید اما تنها {size2} فضا باقی مانده است",
    "Upload cancelled." : "بار گذاری لغو شد",
    "Could not get result from server." : "امکان دریافت نتایج از سرور وجود ندارد.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "آپلودکردن پرونده در حال پیشرفت است. در صورت خروج از صفحه آپلود لغو میگردد. ",
    "Actions" : "فعالیت ها",
    "Download" : "دانلود",
    "Rename" : "تغییرنام",
    "Delete" : "حذف",
    "Details" : "جزئیات",
    "Select" : "انتخاب",
    "Pending" : "در انتظار",
    "Unable to determine date" : "امکان تعیین تاریخ وجود ندارد",
    "This operation is forbidden" : "این عملیات غیرمجاز است",
    "This directory is unavailable, please check the logs or contact the administrator" : "پوشه‌ در دسترس نیست، لطفا لاگ‌ها را بررسی کنید یا به مدیر سیستم اطلاع دهید",
    "Error moving file." : "خطا در انتقال فایل.",
    "Error moving file" : "خطا در انتقال فایل",
    "Error" : "خطا",
    "{new_name} already exists" : "{نام _جدید} در حال حاضر وجود دارد.",
    "Could not rename file" : "امکان تغییر نام وجود ندارد",
    "Could not create file" : "امکان ایجاد فایل وجود ندارد",
    "Could not create folder" : "امکان ایجاد پوشه وجود ندارد",
    "Error deleting file." : "خطا در حذف فایل.",
    "No entries in this folder match '{filter}'" : "هیچ ورودی‌ای با  '{filter}' تطبیق ندارد",
    "Name" : "نام",
    "Size" : "اندازه",
    "Modified" : "تاریخ",
    "_%n folder_::_%n folders_" : ["%n پوشه"],
    "_%n file_::_%n files_" : ["%n فایل"],
    "{dirs} and {files}" : "{dirs} و {files}",
    "You don’t have permission to upload or create files here" : "شما دسترسی مجاز برای آپلود یا ایجاد فایل در اینجا را ندارید",
    "_Uploading %n file_::_Uploading %n files_" : ["در حال بارگذاری %n فایل"],
    "New" : "جدید",
    "\"{name}\" is an invalid file name." : "\"{name}\" نامی نامعتبر برای فایل است.",
    "File name cannot be empty." : "نام پرونده نمی تواند خالی باشد.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "فضای ذخیر‌سازی {owner}  پر شده است، امکان بروزرسانی یا هم‌گام‌سازی بیشتر وجود ندارد!",
    "Your storage is full, files can not be updated or synced anymore!" : "فضای ذخیره ی شما کاملا پر است، بیش از این فایلها بهنگام یا همگام سازی نمی توانند بشوند!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "فضای  {owner} تقریبا پر شده است ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "فضای ذخیره ی شما تقریبا پر است ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["تطبیق '{filter}'"],
    "Path" : "مسیر",
    "_%n byte_::_%n bytes_" : ["%n بایت"],
    "Favorited" : "برگزیده شده",
    "Favorite" : "برگزیده",
    "{newname} already exists" : "{newname}  هم‌اکنون وجود دارد",
    "Upload" : "بارگزاری",
    "Text file" : "فایل متنی",
    "Folder" : "پوشه",
    "New folder" : "پوشه جدید",
    "An error occurred while trying to update the tags" : "یک خطا در حین بروزرسانی برچسب‌ها رخ داده است",
    "A new file or folder has been <strong>created</strong>" : "فایل یا پوشه ای <strong>ایجاد</strong> شد",
    "A file or folder has been <strong>changed</strong>" : "فایل یا پوشه ای به <strong>تغییر</strong> یافت",
    "A file or folder has been <strong>deleted</strong>" : "فایل یا پوشه ای به <strong>حذف</strong> شد",
    "A file or folder has been <strong>restored</strong>" : "یک فایل یا پوشه <strong>بازگردانی شد</strong>",
    "You created %1$s" : "شما %1$s را ایجاد کردید",
    "%2$s created %1$s" : "%2$s مورد %1$s را ایجاد کرد",
    "%1$s was created in a public folder" : "%1$s در پوشه ی عمومی ایجاد شد",
    "You changed %1$s" : "شما %1$s را تغییر دادید",
    "%2$s changed %1$s" : "%2$s مورد %1$s را تغییر داد",
    "You deleted %1$s" : "شما %1$s را حذف کردید",
    "%2$s deleted %1$s" : "%2$s مورد %1$s را حذف کرد",
    "You restored %1$s" : "شما %1$s را بازگردانی کردید",
    "%2$s restored %1$s" : "%2$s %1$s را بازگردانی کرد",
    "Changed by %2$s" : "تغییریافته توسط %2$s",
    "Deleted by %2$s" : "حذف شده توسط %2$s",
    "Restored by %2$s" : "بازگردانی شده توسط  %2$s",
    "%s could not be renamed as it has been deleted" : "امکان تغییر نام %s با توجه به حذف شدن آن وجود ندارد",
    "%s could not be renamed" : "%s نمیتواند تغییر نام دهد.",
    "Upload (max. %s)" : "آپلود (بیشترین سایز %s)",
    "File handling" : "اداره پرونده ها",
    "Maximum upload size" : "حداکثر اندازه بارگزاری",
    "max. possible: " : "حداکثرمقدارممکن:",
    "Save" : "ذخیره",
    "Can not be edited from here due to insufficient permissions." : "با توجه به دسترسی محدود، امکان ویرایش از اینجا وجود ندارد.",
    "Settings" : "تنظیمات",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "از این آدرس استفاده کنید تا <a href=\"%s\" target=\"_blank\">بتوانید به فایل‌های خود توسط WebDAV دسترسی پیدا کنید</a>",
    "Cancel upload" : "متوقف کردن بار گذاری",
    "No files in here" : "هیچ فایلی اینجا وجود ندارد",
    "Upload some content or sync with your devices!" : "محتوایی را آپلود کنید یا با دستگاه خود همگام‌سازی کنید!",
    "No entries found in this folder" : "هیچ ورودی‌ای در این پوشه وجود ندارد",
    "Select all" : "انتخاب همه",
    "Upload too large" : "سایز فایل برای آپلود زیاد است(م.تنظیمات در php.ini)",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "فایلها بیش از حد تعیین شده در این سرور هستند\nمترجم:با تغییر فایل php,ini میتوان این محدودیت را برطرف کرد",
    "Files are being scanned, please wait." : "پرونده ها در حال بازرسی هستند لطفا صبر کنید",
    "Currently scanning" : "در حال اسکن",
    "No favorites" : "هیچ برگزیده",
    "Files and folders you mark as favorite will show up here" : "فایل‌ها و پوشه‌های انتخاب شده به عنوان برگزیده توسط شما، در اینجا نمایش داده می‌شود"
},
"nplurals=1; plural=0;");

==> owncloud-9.0.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/files/l10n/fa.js <==
OC.L10N.register(
    "files",
    {
    "Storage not available" : "فضای ذخیره سازی موجود نیست",
    "Storage invalid" : "فضای ذخیره‌سازی نامعتبر",
    "Unknown error" : "خطای نامشخص",
    "Unable to set upload directory." : "قادر به تنظیم پوشه آپلود نمی باشد.",
    "Invalid Token" : "رمز نامعتبر",
    "No file was uploaded. Unknown error" : "هیچ فایلی آپلود نشد.خطای ناشناس",
    "There is no error, the file uploaded with success" : "هیچ خطایی نیست بارگذاری پرونده موفقیت آمیز بود",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "پرونده آپلود شده بیش ازدستور  ماکزیمم_حجم فایل_برای آپلود در   php.ini استفاده کرده است.",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "حداکثر حجم قابل بار گذاری از طریق HTML MAX_FILE_SIZE است",
    "The uploaded file was only partially uploaded" : "پرونده بارگذاری شده فقط تاحدودی بارگذاری شده",
    "No file was uploaded" : "هیچ پروندهای بارگذاری نشده",
    "Missing a temporary folder" : "یک پوشه موقت گم شده",
    "Failed to write to disk" : "نوشتن بر روی دیسک سخت ناموفق بود",
    "Not enough storage available" : "فضای کافی در دسترس نیست",
    "The target folder has been moved or deleted." : "پوشه مقصد انتقال یافته یا حذف شده است.",
    "Upload failed. Could not find uploaded file" : "خطا در آپلود. امکان یافتن فایل‌های آپلود شده وجود ندارد",
    "Upload failed. Could not get file info." : "خطای آپلود. امکان دریافت جزئیات فایل وجود ندارد.",
    "Invalid directory." : "فهرست راهنما نامعتبر می باشد.",
    "Files" : "پرونده‌ها",
    "All files" : "تمامی فایل‌ها",
    "Favorites" : "موارد محبوب",
    "Home" : "خانه",
    "Close" : "بستن",
    "Upload cancelled." : "بار گذاری لغو شد",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "امکان آپلود {filename} وجود ندارد، پوشه‌ای با این نام یا فایلی با حجم 0 بایت با این نام وجود دارد",
    "Total file size {size1} exceeds upload limit {size2}" : "مجموع سایز {size1} بیشتر از محدودیت آپلود {size2} است",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "ظرفیت لازم وجود ندارد، شما آپلودی با حجم {size1}  را انجام میدهید اما تنها {size2} فضا باقی مانده است",
    "Could not get result from server." : "امکان دریافت نتایج از سرور وجود ندارد.",
    "File upload is in progress. Leaving the page now will cancel the upload." : "آپلودکردن پرونده در حال پیشرفت است. در صورت خروج از صفحه آپلود لغو میگردد. ",
    "Actions" : "فعالیت ها",
    "Download" : "دانلود",
    "Rename" : "تغییرنام",
    "Delete" : "حذف",
    "Unshare" : "لغو اشتراک",
    "Details" : "جزئیات",
    "Select" : "انتخاب",
    "Pending" : "در انتظار",
    "Unable to determine date" : "امکان تعیین تاریخ وجود ندارد",
    "This operation is forbidden" : "این عملیات غیرمجاز است",
    "This directory is unavailable, please check the logs or contact the administrator" : "پوشه‌ در دسترس نیست، لطفا لاگ‌ها را بررسی کنید یا به مدیر سیستم اطلاع دهید",
    "No entries in this folder match '{filter}'" : "هیچ ورودی‌ای با  '{filter}' تطبیق ندارد",
    "Name" : "نام",
    "Size" : "اندازه",
    "Modified" : "تاریخ",
    "_%n folder_::_%n folders_" : ["%n پوشه"],
    "_%n file_::_%n files_" : ["%n فایل"],
    "{dirs} and {files}" : "{dirs} و {files}",
    "You don’t have permission to upload or create files here" : "شما دسترسی مجاز برای آپلود یا ایجاد فایل در اینجا را ندارید",
    "_Uploading %n file_::_Uploading %n files_" : ["در حال بارگذاری %n فایل"],
    "New" : "جدید",
    "\"{name}\" is an invalid file name." : "\"{name}\" نامی نامعتبر برای فایل است.",
    "File name cannot be empty." : "نام پرونده نمی تواند خالی باشد.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "فضای ذخیر‌سازی {owner}  پر شده است، امکان بروزرسانی یا هم‌گام‌سازی بیشتر وجود ندارد!",
    "Your storage is full, files can not be updated or synced anymore!" : "فضای ذخیره ی شما کاملا پر است، بیش از این فایلها بهنگام یا همگام سازی نمی توانند بشوند!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "فضای  {owner} تقریبا پر شده است ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "فضای ذخیره ی شما تقریبا پر است ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["تطبیق '{filter}'"],
    "Path" : "مسیر",
    "_%n byte_::_%n bytes_" : ["%n بایت"],
    "Favorited" : "برگزیده شده",
    "Favorite" : "برگزیده",
    "Folder" : "پوشه",
    "New folder" : "پوشه جدید",
    "{newname} already exists" : "{newname}  هم‌اکنون وجود دارد",
    "Upload" : "بارگزاری",
    "An error occurred while trying to update the tags" : "یک خطا در حین بروزرسانی برچسب‌ها رخ داده است",
    "A new file or folder has been <strong>created</strong>" : "فایل یا پوشه ای <strong>ایجاد</strong> شد",
    "A file or folder has been <strong>changed</strong>" : "فایل یا پوشه ای به <strong>تغییر</strong> یافت",
    "A file or folder has been <strong>deleted</strong>" : "فایل یا پوشه ای به <strong>حذف</strong> شد",
    "A file or folder has been <strong>restored</strong>" : "یک فایل یا پوشه <strong>بازگردانی شد</strong>",
    "You created %1$s" : "شما %1$s را ایجاد کردید",
    "%2$s created %1$s" : "%2$s مورد %1$s را ایجاد کرد",
    "%1$s was created in a public folder" : "%1$s در پوشه ی عمومی ایجاد شد",
    "You changed %1$s" : "شما %1$s را تغییر دادید",
    "%2$s changed %1$s" : "%2$s مورد %1$s را تغییر داد",
    "You deleted %1$s" : "شما %1$s را حذف کردید",
    "%2$s deleted %1$s" : "%2$s مورد %1$s را حذف کرد",
    "You restored %1$s" : "شما %1$s را بازگردانی کردید",
    "%2$s restored %1$s" : "%2$s %1$s را بازگردانی کرد",
    "Changed by %2$s" : "تغییریافته توسط %2$s",
    "Deleted by %2$s" : "حذف شده توسط %2$s",
    "Restored by %2$s" : "بازگردانی شده توسط  %2$s",
    "Upload (max. %s)" : "آپلود (بیشترین سایز %s)",
    "File handling" : "اداره پرونده ها",
    "Maximum upload size" : "حداکثر اندازه بارگزاری",
    "max. possible: " : "حداکثرمقدارممکن:",
    "Save" : "ذخیره",
    "Settings" : "تنظیمات",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\">access your Files via WebDAV</a>" : "از این آدرس استفاده کنید تا <a href=\"%s\" target=\"_blank\">بتوانید به فایل‌های خود توسط WebDAV دسترسی پیدا کنید</a>",
    "Cancel upload" : "متوقف کردن بار گذاری",
    "No files in here" : "هیچ فایلی اینجا وجود ندارد",
    "Upload some content or sync with your devices!" : "محتوایی را آپلود کنید یا با دستگاه خود همگام‌سازی کنید!",
    "No entries found in this folder" : "هیچ ورودی‌ای در این پوشه وجود ندارد",
    "Select all" : "انتخاب همه",
    "Upload too large" : "سایز فایل برای آپلود زیاد است(م.تنظیمات در php.ini)",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "فایلها بیش از حد تعیین شده در این سرور هستند\nمترجم:با تغییر فایل php,ini میتوان این محدودیت را برطرف کرد",
    "No favorites" : "هیچ برگزیده",
    "Files and folders you mark as favorite will show up here" : "فایل‌ها و پوشه‌های انتخاب شده به عنوان برگزیده توسط شما، در اینجا نمایش داده می‌شود",
    "Text file" : "فایل متنی",
    "Changed by %2$s" : "تغییریافته توسط %2$s",
    "Deleted by %2$s" : "حذف شده توسط %2$s",
    "Restored by %2$s" : "بازگردانی شده توسط  %2$s",
    "You changed %1$s" : "شما %1$s را تغییر دادید",
    "You created %1$s" : "شما %1$s را ایجاد کردید",
    "You deleted %1$s" : "شما %1$s را حذف کردید",
    "You restored %1$s" : "شما %1$s را بازگردانی کردید"
},
"nplurals=1; plural=0;");
